package au.com.infomedix.cpf4.ds;

import javax.annotation.Resource;
import javax.ejb.LocalBean;
import javax.ejb.Stateless;
import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;
import javax.ejb.TransactionManagement;
import javax.ejb.TransactionManagementType;
import javax.inject.Inject;
import javax.jcr.LoginException;
import javax.jcr.Node;
import javax.jcr.Repository;
import javax.jcr.RepositoryException;
import javax.jcr.Session;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.jboss.solder.logging.Logger;


/**
 * Session Bean implementation class PatientRecordOperation
 */
@Stateless
public class PatientRecordOperation
{
//    @Inject
//    private Logger log;

    @Resource(name = "java:/jcr/sample")
    private Repository repository;

    /**
     * Default constructor.
     */
    public PatientRecordOperation()
    {
        // TODO Auto-generated constructor stub
    }

    /**
     * Add a new patient to the repository. This initialises the top level node and adds the
     * sections to that patient node.
     *
     * @param namespace the namespace or domain for the patient urno (typically this identifies the PMI that allocated the urno)
     * @param urno the patient identifier, must be unique within the namespace.
     */
    public void addPatient(String namespace,
                           String urno)
    {
//    	log.infov("Creating patient {0}:{1}", namespace,urno);
        Session session = null;
        String patientPath = namespace + "." + urno;
        try
        {
            // repository = (Repository)new InitialContext().lookup("java:/jcr/sample");
            session = repository.login();
            Node n = session.getRootNode();
            if(n.hasNode(patientPath))
            {
            	throw new RuntimeException("Patient \""+patientPath+"\" already exists");
            }
            
            Node patientNode = n.addNode(patientPath /*, "inf:patient"*/);
            patientNode.setProperty("masterNs", namespace);
            patientNode.setProperty("masterId",urno);
            Node patientId = patientNode.addNode(patientPath/*, "inf:patientId"*/);
            patientId.setProperty("ns", namespace);
            patientId.setProperty("id",urno);
            
            session.save();
        }
        catch(LoginException e)
        {
            throw new RuntimeException("Failed JCR repository login", e);
        }
        catch(RepositoryException e)
        {
        	throw new RuntimeException("Unexpected JCR repository error", e);
        } 
//        catch (NamingException e)
//        {
//            throw new RuntimeException("Failed to find repository", e);
//        }
        finally
        {
            if(session != null)
            {
                session.logout();
            }
        }
    }
}